@@ -39,7 +39,7 @@ sub _tag_start {
   if ($tag eq "strong" or $tag eq "b") {
     $irctext .= $BOLD unless $b;
     $b = 1;
-  } elsif ($tag eq "em" or $tag eq "italic") {
+  } elsif ($tag eq "em" or $tag eq "i") {
     $irctext .= $INVERSE unless $i;
     $i = 1;
   } elsif ($tag eq "u") {
@@ -54,10 +54,10 @@ sub _tag_start {
 sub _tag_end {
   my $tag = shift;
 
-  if ($tag eq "strong") {
+  if ($tag eq "strong" or $tag eq "b") {
     $irctext .= $BOLD if $b;
     $b = 0;
-  } elsif ($tag eq "em") {
+  } elsif ($tag eq "em" or $tag eq "i") {
     $irctext .= $INVERSE if $i;
     $i = 0;
   } elsif ($tag eq "u") {
